developerscripttools.AbjDevScript
=================================

.. abjad-lineage:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript

.. autoclass:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.developer_script_aliases
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.developer_script_classes
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.developer_script_program_names
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjDevScript.AbjDevScript.AbjDevScript.__repr__
   :noindex:
